@@ -6,6 +6,8 @@ use serde::de::DeserializeOwned;
 pub const EMPTY_BODY_JSON_MSG: &str = "expected a json body but no response body was present";
 pub const EMPTY_BODY_TEXT_MSG: &str = "expected a text body but no response body was present";
 pub const EMPTY_BODY_BYTES_MSG: &str = "expected a response body but no response body was present";
+pub const EXPECTED_BODY_PRESENT_MSG: &str = "expected a response body but no response body was present";
+pub const EXPECTED_BODY_ABSENT_MSG: &str = "expected no response body but a response body was present";
 
 pub fn assert_json_body_eq<B>(actual: B, expected: B) where B: DeserializeOwned + PartialEq + Debug + Unpin {
     assert_eq!(actual, expected, "expected json body {:?} to be equal to {:?} but was not", actual, expected);
