@@ -1,4 +1,3 @@
-use stubr::Stubr;
 use surf::get;
 
 use asserhttp::*;
@@ -7,29 +6,29 @@ mod eq {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/eq.json")]
     async fn should_expect_status_eq() {
-        let srv = Stubr::start("tests/stubs/status/eq.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_eq(200);
+        get(stubr.uri()).await.unwrap().expect_status_eq(200);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '100' but was '200'")]
+    #[stubr::mock("status/eq.json")]
+    #[async_std::test]
     async fn expect_status_eq_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/eq.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_eq(100);
+        get(stubr.uri()).await.unwrap().expect_status_eq(100);
     }
 
     #[async_std::test]
+    #[stubr::mock("status/eq.json")]
     async fn result_should_expect_status_eq() {
-        let srv = Stubr::start("tests/stubs/status/eq.json").await;
-        get(&srv.uri()).await.expect_status_eq(200);
+        get(stubr.uri()).await.expect_status_eq(200);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '100' but was '200'")]
+    #[stubr::mock("status/eq.json")]
+    #[async_std::test]
     async fn result_expect_status_eq_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/eq.json").await;
-        get(&srv.uri()).await.expect_status_eq(100);
+        get(stubr.uri()).await.expect_status_eq(100);
     }
 }
 
@@ -37,30 +36,30 @@ mod ok {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/ok.json")]
     async fn should_expect_status_ok() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_ok();
+        get(stubr.uri()).await.unwrap().expect_status_ok();
     }
 
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '200' but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn expect_status_ok_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_ok();
+        get(stubr.uri()).await.unwrap().expect_status_ok();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/ok.json")]
     async fn result_should_expect_status_ok() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_ok();
+        get(stubr.uri()).await.expect_status_ok();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '200' but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn result_expect_status_ok_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_ok();
+        get(stubr.uri()).await.expect_status_ok();
     }
 }
 
@@ -68,29 +67,29 @@ mod created {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn should_expect_status_created() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_created();
+        get(stubr.uri()).await.unwrap().expect_status_created();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '201' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_created_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_created();
+        get(stubr.uri()).await.unwrap().expect_status_created();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn result_should_expect_status_created() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_created();
+        get(stubr.uri()).await.expect_status_created();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '201' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_created_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_created();
+        get(stubr.uri()).await.expect_status_created();
     }
 }
 
@@ -98,29 +97,29 @@ mod accepted {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/accepted.json")]
     async fn should_expect_status_accepted() {
-        let srv = Stubr::start("tests/stubs/status/accepted.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_accepted();
+        get(stubr.uri()).await.unwrap().expect_status_accepted();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '202' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_accepted_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_accepted();
+        get(stubr.uri()).await.unwrap().expect_status_accepted();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/accepted.json")]
     async fn result_should_expect_status_accepted() {
-        let srv = Stubr::start("tests/stubs/status/accepted.json").await;
-        get(&srv.uri()).await.expect_status_accepted();
+        get(stubr.uri()).await.expect_status_accepted();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '202' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_accepted_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_accepted();
+        get(stubr.uri()).await.expect_status_accepted();
     }
 }
 
@@ -128,29 +127,29 @@ mod no_content {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/no-content.json")]
     async fn should_expect_status_no_content() {
-        let srv = Stubr::start("tests/stubs/status/no-content.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_no_content();
+        get(stubr.uri()).await.unwrap().expect_status_no_content();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '204' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_no_content_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_no_content();
+        get(stubr.uri()).await.unwrap().expect_status_no_content();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/no-content.json")]
     async fn result_should_expect_status_no_content() {
-        let srv = Stubr::start("tests/stubs/status/no-content.json").await;
-        get(&srv.uri()).await.expect_status_no_content();
+        get(stubr.uri()).await.expect_status_no_content();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '204' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_no_content_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_no_content();
+        get(stubr.uri()).await.expect_status_no_content();
     }
 }
 
@@ -158,29 +157,29 @@ mod partial_content {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/partial-content.json")]
     async fn should_expect_status_partial_content() {
-        let srv = Stubr::start("tests/stubs/status/partial-content.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_partial_content();
+        get(stubr.uri()).await.unwrap().expect_status_partial_content();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '206' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_partial_content_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_partial_content();
+        get(stubr.uri()).await.unwrap().expect_status_partial_content();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/partial-content.json")]
     async fn result_should_expect_status_partial_content() {
-        let srv = Stubr::start("tests/stubs/status/partial-content.json").await;
-        get(&srv.uri()).await.expect_status_partial_content();
+        get(stubr.uri()).await.expect_status_partial_content();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '206' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_partial_content_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_partial_content();
+        get(stubr.uri()).await.expect_status_partial_content();
     }
 }
 
@@ -188,29 +187,29 @@ mod bad_request {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/bad-request.json")]
     async fn should_expect_status_bad_request() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_bad_request();
+        get(stubr.uri()).await.unwrap().expect_status_bad_request();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '400' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_bad_request_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_bad_request();
+        get(stubr.uri()).await.unwrap().expect_status_bad_request();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/bad-request.json")]
     async fn result_should_expect_status_bad_request() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.expect_status_bad_request();
+        get(stubr.uri()).await.expect_status_bad_request();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '400' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_bad_request_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_bad_request();
+        get(stubr.uri()).await.expect_status_bad_request();
     }
 }
 
@@ -218,29 +217,29 @@ mod unauthorized {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/unauthorized.json")]
     async fn should_expect_status_unauthorized() {
-        let srv = Stubr::start("tests/stubs/status/unauthorized.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_unauthorized();
+        get(stubr.uri()).await.unwrap().expect_status_unauthorized();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '401' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_unauthorized_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_unauthorized();
+        get(stubr.uri()).await.unwrap().expect_status_unauthorized();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/unauthorized.json")]
     async fn result_should_expect_status_unauthorized() {
-        let srv = Stubr::start("tests/stubs/status/unauthorized.json").await;
-        get(&srv.uri()).await.expect_status_unauthorized();
+        get(stubr.uri()).await.expect_status_unauthorized();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '401' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_unauthorized_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_unauthorized();
+        get(stubr.uri()).await.expect_status_unauthorized();
     }
 }
 
@@ -248,29 +247,29 @@ mod forbidden {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/forbidden.json")]
     async fn should_expect_status_forbidden() {
-        let srv = Stubr::start("tests/stubs/status/forbidden.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_forbidden();
+        get(stubr.uri()).await.unwrap().expect_status_forbidden();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '403' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_forbidden_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_forbidden();
+        get(stubr.uri()).await.unwrap().expect_status_forbidden();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/forbidden.json")]
     async fn result_should_expect_status_forbidden() {
-        let srv = Stubr::start("tests/stubs/status/forbidden.json").await;
-        get(&srv.uri()).await.expect_status_forbidden();
+        get(stubr.uri()).await.expect_status_forbidden();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '403' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_forbidden_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_forbidden();
+        get(stubr.uri()).await.expect_status_forbidden();
     }
 }
 
@@ -278,29 +277,29 @@ mod not_found {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/not_found.json")]
     async fn should_expect_status_not_found() {
-        let srv = Stubr::start("tests/stubs/status/not_found.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_not_found();
+        get(stubr.uri()).await.unwrap().expect_status_not_found();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '404' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_not_found_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_not_found();
+        get(stubr.uri()).await.unwrap().expect_status_not_found();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/not_found.json")]
     async fn result_should_expect_status_not_found() {
-        let srv = Stubr::start("tests/stubs/status/not_found.json").await;
-        get(&srv.uri()).await.expect_status_not_found();
+        get(stubr.uri()).await.expect_status_not_found();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '404' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_not_found_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_not_found();
+        get(stubr.uri()).await.expect_status_not_found();
     }
 }
 
@@ -308,29 +307,29 @@ mod conflict {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/conflict.json")]
     async fn should_expect_status_conflict() {
-        let srv = Stubr::start("tests/stubs/status/conflict.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_conflict();
+        get(stubr.uri()).await.unwrap().expect_status_conflict();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '409' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_conflict_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_conflict();
+        get(stubr.uri()).await.unwrap().expect_status_conflict();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/conflict.json")]
     async fn result_should_expect_status_conflict() {
-        let srv = Stubr::start("tests/stubs/status/conflict.json").await;
-        get(&srv.uri()).await.expect_status_conflict();
+        get(stubr.uri()).await.expect_status_conflict();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '409' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_conflict_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_conflict();
+        get(stubr.uri()).await.expect_status_conflict();
     }
 }
 
@@ -338,29 +337,29 @@ mod gone {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/gone.json")]
     async fn should_expect_status_gone() {
-        let srv = Stubr::start("tests/stubs/status/gone.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_gone();
+        get(stubr.uri()).await.unwrap().expect_status_gone();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '410' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_gone_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_gone();
+        get(stubr.uri()).await.unwrap().expect_status_gone();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/gone.json")]
     async fn result_should_expect_status_gone() {
-        let srv = Stubr::start("tests/stubs/status/gone.json").await;
-        get(&srv.uri()).await.expect_status_gone();
+        get(stubr.uri()).await.expect_status_gone();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '410' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_gone_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_gone();
+        get(stubr.uri()).await.expect_status_gone();
     }
 }
 
@@ -368,29 +367,29 @@ mod internal_server_error {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/server-error.json")]
     async fn should_expect_status_internal_server_error() {
-        let srv = Stubr::start("tests/stubs/status/server-error.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_internal_server_error();
+        get(stubr.uri()).await.unwrap().expect_status_internal_server_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '500' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_internal_server_error_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_internal_server_error();
+        get(stubr.uri()).await.unwrap().expect_status_internal_server_error();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/server-error.json")]
     async fn result_should_expect_status_internal_server_error() {
-        let srv = Stubr::start("tests/stubs/status/server-error.json").await;
-        get(&srv.uri()).await.expect_status_internal_server_error();
+        get(stubr.uri()).await.expect_status_internal_server_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be '500' but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_internal_server_error_should_panic() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_internal_server_error();
+        get(stubr.uri()).await.expect_status_internal_server_error();
     }
 }
 
@@ -398,55 +397,55 @@ mod range {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn should_expect_status_in_inclusive_lower_range() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_in_range(201, 300);
+        get(stubr.uri()).await.unwrap().expect_status_in_range(201, 300);
     }
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn should_expect_status_in_exclusive_upper_range() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_in_range(200, 202);
+        get(stubr.uri()).await.unwrap().expect_status_in_range(200, 202);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [202;300[ but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn expect_status_in_range_should_panic_when_lower() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_in_range(202, 300);
+        get(stubr.uri()).await.unwrap().expect_status_in_range(202, 300);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [200;201[ but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn expect_status_in_range_should_panic_when_upper() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_in_range(200, 201);
+        get(stubr.uri()).await.unwrap().expect_status_in_range(200, 201);
     }
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn result_should_expect_status_in_inclusive_lower_range() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_in_range(201, 300);
+        get(stubr.uri()).await.expect_status_in_range(201, 300);
     }
 
     #[async_std::test]
+    #[stubr::mock("status/created.json")]
     async fn result_should_expect_status_in_exclusive_upper_range() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_in_range(200, 202);
+        get(stubr.uri()).await.expect_status_in_range(200, 202);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [202;300[ but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn result_expect_status_in_range_should_panic_when_lower() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_in_range(202, 300);
+        get(stubr.uri()).await.expect_status_in_range(202, 300);
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [200;201[ but was '201'")]
+    #[stubr::mock("status/created.json")]
+    #[async_std::test]
     async fn result_expect_status_in_range_should_panic_when_upper() {
-        let srv = Stubr::start("tests/stubs/status/created.json").await;
-        get(&srv.uri()).await.expect_status_in_range(200, 201);
+        get(stubr.uri()).await.expect_status_in_range(200, 201);
     }
 }
 
@@ -454,29 +453,29 @@ mod success {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/ok.json")]
     async fn should_expect_status_success() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_success();
+        get(stubr.uri()).await.unwrap().expect_status_success();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [200;300[ but was '400'")]
+    #[stubr::mock("status/bad-request.json")]
+    #[async_std::test]
     async fn expect_status_success_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_success();
+        get(stubr.uri()).await.unwrap().expect_status_success();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/ok.json")]
     async fn result_should_expect_status_success() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_success();
+        get(stubr.uri()).await.expect_status_success();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [200;300[ but was '400'")]
+    #[stubr::mock("status/bad-request.json")]
+    #[async_std::test]
     async fn result_expect_status_success_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.expect_status_success();
+        get(stubr.uri()).await.expect_status_success();
     }
 }
 
@@ -484,29 +483,29 @@ mod redirection {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/moved-permanently.json")]
     async fn should_expect_status_redirection() {
-        let srv = Stubr::start("tests/stubs/status/moved-permanently.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_redirection();
+        get(stubr.uri()).await.unwrap().expect_status_redirection();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [300;400[ but was '400'")]
+    #[stubr::mock("status/bad-request.json")]
+    #[async_std::test]
     async fn expect_status_redirection_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_redirection();
+        get(stubr.uri()).await.unwrap().expect_status_redirection();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/moved-permanently.json")]
     async fn result_should_expect_status_redirection() {
-        let srv = Stubr::start("tests/stubs/status/moved-permanently.json").await;
-        get(&srv.uri()).await.expect_status_redirection();
+        get(stubr.uri()).await.expect_status_redirection();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [300;400[ but was '400'")]
+    #[stubr::mock("status/bad-request.json")]
+    #[async_std::test]
     async fn result_expect_status_redirection_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.expect_status_redirection();
+        get(stubr.uri()).await.expect_status_redirection();
     }
 }
 
@@ -514,29 +513,29 @@ mod client_error {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/bad-request.json")]
     async fn should_expect_status_client_error() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_client_error();
+        get(stubr.uri()).await.unwrap().expect_status_client_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [400;500[ but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_client_error_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_client_error();
+        get(stubr.uri()).await.unwrap().expect_status_client_error();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/bad-request.json")]
     async fn result_should_expect_status_client_error() {
-        let srv = Stubr::start("tests/stubs/status/bad-request.json").await;
-        get(&srv.uri()).await.expect_status_client_error();
+        get(stubr.uri()).await.expect_status_client_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [400;500[ but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_client_error_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_client_error();
+        get(stubr.uri()).await.expect_status_client_error();
     }
 }
 
@@ -544,28 +543,28 @@ mod server_error {
     use super::*;
 
     #[async_std::test]
+    #[stubr::mock("status/server-error.json")]
     async fn should_expect_status_server_error() {
-        let srv = Stubr::start("tests/stubs/status/server-error.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_server_error();
+        get(stubr.uri()).await.unwrap().expect_status_server_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [500;600[ but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn expect_status_server_error_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.unwrap().expect_status_server_error();
+        get(stubr.uri()).await.unwrap().expect_status_server_error();
     }
 
     #[async_std::test]
+    #[stubr::mock("status/server-error.json")]
     async fn result_should_expect_status_server_error() {
-        let srv = Stubr::start("tests/stubs/status/server-error.json").await;
-        get(&srv.uri()).await.expect_status_server_error();
+        get(stubr.uri()).await.expect_status_server_error();
     }
 
-    #[async_std::test]
     #[should_panic(expected = "expected status to be in [500;600[ but was '200'")]
+    #[stubr::mock("status/ok.json")]
+    #[async_std::test]
     async fn result_expect_status_server_error_should_panic_when_not() {
-        let srv = Stubr::start("tests/stubs/status/ok.json").await;
-        get(&srv.uri()).await.expect_status_server_error();
+        get(stubr.uri()).await.expect_status_server_error();
     }
 }
\ No newline at end of file
